@@ -22,7 +22,7 @@ from argh.compat import OrderedDict
 from argh.constants import (ATTR_ALIASES, ATTR_ARGS, ATTR_NAME,
                             ATTR_INFER_ARGS_FROM_SIGNATURE,
                             ATTR_EXPECTS_NAMESPACE_OBJECT,
-                            PARSER_FORMATTER)
+                            PARSER_FORMATTER, DEFAULT_ARGUMENT_TEMPLATE)
 from argh.utils import get_subparsers, get_arg_spec
 from argh.exceptions import AssemblingError
 
@@ -42,7 +42,8 @@ def _check_support_aliases():
 
 
 SUPPORTS_ALIASES = _check_support_aliases()
-""" Calculated on load. If `True`, current version of argparse supports
+"""
+Calculated on load. If `True`, current version of argparse supports
 alternative command names (can be set via :func:`~argh.decorators.aliases`).
 """
 
@@ -196,7 +197,8 @@ def _get_dest(parser, argspec):
 
 
 def set_default_command(parser, function):
-    """ Sets default command (i.e. a function) for given parser.
+    """
+    Sets default command (i.e. a function) for given parser.
 
     If `parser.description` is empty and the function has a docstring,
     it is used as the description.
@@ -309,6 +311,8 @@ def set_default_command(parser, function):
 
     for draft in command_args:
         draft = draft.copy()
+        if 'help' not in draft:
+            draft.update(help=DEFAULT_ARGUMENT_TEMPLATE)
         dest_or_opt_strings = draft.pop('option_strings')
         if parser.add_help and '-h' in dest_or_opt_strings:
             dest_or_opt_strings = [x for x in dest_or_opt_strings if x != '-h']
@@ -328,7 +332,8 @@ def set_default_command(parser, function):
 
 def add_commands(parser, functions, namespace=None, title=None,
                  description=None, help=None):
-    """Adds given functions as commands to given parser.
+    """
+    Adds given functions as commands to given parser.
 
     :param parser:
 
