@@ -23,19 +23,20 @@ from argh.constants import (ATTR_WRAPPED_EXCEPTIONS,
                             PARSER_FORMATTER)
 from argh.completion import autocomplete
 from argh.assembling import add_commands, set_default_command
-from argh.exceptions import CommandError
+from argh.exceptions import DispatchingError, CommandError
 from argh.utils import get_arg_spec
 
 
 __all__ = ['dispatch', 'dispatch_command', 'dispatch_commands',
-           'PARSER_FORMATTER']
+           'PARSER_FORMATTER', 'EntryPoint']
 
 
 def dispatch(parser, argv=None, add_help_command=True,
              completion=True, pre_call=None,
              output_file=sys.stdout, errors_file=sys.stderr,
              raw_output=False, namespace=None):
-    """Parses given list of arguments using given parser, calls the relevant
+    """
+    Parses given list of arguments using given parser, calls the relevant
     function and prints the result.
 
     The target function should expect one positional argument: the
@@ -138,7 +139,8 @@ def dispatch(parser, argv=None, add_help_command=True,
 
 
 def _execute_command(args, errors_file):
-    """Asserts that ``args.function`` is present and callable. Tries different
+    """
+    Asserts that ``args.function`` is present and callable. Tries different
     approaches to calling the function (with an `argparse.Namespace` object or
     with ordinary signature). Yields the results line by line.
 
@@ -208,7 +210,8 @@ def _execute_command(args, errors_file):
 
 
 def dispatch_command(function, *args, **kwargs):
-    """ A wrapper for :func:`dispatch` that creates a one-command parser.
+    """
+    A wrapper for :func:`dispatch` that creates a one-command parser.
     Uses :attr:`PARSER_FORMATTER`.
 
     This::
@@ -229,7 +232,8 @@ def dispatch_command(function, *args, **kwargs):
 
 
 def dispatch_commands(functions, *args, **kwargs):
-    """ A wrapper for :func:`dispatch` that creates a parser, adds commands to
+    """
+    A wrapper for :func:`dispatch` that creates a parser, adds commands to
     the parser and dispatches them.
     Uses :attr:`PARSER_FORMATTER`.
 
@@ -247,3 +251,57 @@ def dispatch_commands(functions, *args, **kwargs):
     parser = argparse.ArgumentParser(formatter_class=PARSER_FORMATTER)
     add_commands(parser, functions)
     dispatch(parser, *args, **kwargs)
+
+
+class EntryPoint(object):
+    """
+    An object to which functions can be attached and then dispatched.
+
+    When called with an argument, the argument (a function) is registered
+    at this entry point as a command.
+
+    When called without an argument, dispatching is triggered with all
+    previously registered commands.
+
+    Usage::
+
+        from argh import EntryPoint
+
+        entrypoint = EntryPoint()
+
+        @entrypoint
+        def ls():
+            for i in range(10):
+                print i
+
+        @entrypoint
+        def greet():
+            print 'hello'
+
+        if __name__ == '__main__':
+            entrypoint()
+
+    """
+    def __init__(self, name=None):
+        self.name = name or 'unnamed'
+        self.commands = []
+
+    def __call__(self, f=None):
+        if f:
+            self._register_command(f)
+            return f
+
+        return self._dispatch()
+
+    def _register_command(self, f):
+        self.commands.append(f)
+
+    def _dispatch(self):
+        if not self.commands:
+            raise DispatchingError('no commands for entry point "{0}"'
+                                   .format(self.name))
+
+        if len(self.commands) == 1:
+            dispatch_command(*self.commands)
+        else:
+            dispatch_commands(self.commands)
